| Title: | Painting Palettes Generator |
|---|---|
| Description: | Color palettes generated from paintings. |
| Authors: | Dean Li [aut, cre] |
| Maintainer: | Dean Li <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.3 |
| Built: | 2026-06-07 08:24:36 UTC |
| Source: | https://github.com/thereallda/paintingr |
Display All Available Palettes
display_all_palettes(n = NULL)display_all_palettes(n = NULL)
n |
Number of palettes to display. All palettes will be displayed in default |
No return value, called for displaying all available palettes.
display_all_palettes()display_all_palettes()
Paintings Palette Generator
paint_palette(name, n, type = c("discrete", "continuous"))paint_palette(name, n, type = c("discrete", "continuous"))
name |
Name of desired palette. Choice are:
|
n |
Number of colors you want. |
type |
Use "discrete" or "continuous". Use "continuous" to automatically interpolate between colors if you want more colors. |
A vector of colors.
paint_palette("Ophelia") paint_palette("Ophelia", n=3) paint_palette("Autumn", n=100, type="continuous")paint_palette("Ophelia") paint_palette("Ophelia", n=3) paint_palette("Autumn", n=100, type="continuous")
Use paint_palette to construct palettes of desired length.
painting_palettespainting_palettes
An object of class list of length 14.